@@ -1,5 +1,5 @@
 class Platform():
-    def __init__(self, id, name, is_brand_missing_from_name, platform_family_id, platform_family_name, model_no, storage_capacity, description, disambiguation, relevance, editions=[]):
+    def __init__(self, id, name, is_brand_missing_from_name, platform_family_id, platform_family_name, model_no, storage_capacity, description, disambiguation, relevance):
         self.id = id
         self.name = name
         self.is_brand_missing_from_name = is_brand_missing_from_name
@@ -10,4 +10,4 @@ class Platform():
         self.description = description
         self.disambiguation = disambiguation
         self.relevance = relevance
-        self.editions = []
+        self.editions = list()
